## Olympus Tags

Tags 0x0000 through 0x0103 are used by some older Olympus cameras, and are the same as Konica/Minolta tags. These tags are also used for some models from other brands such as Acer, BenQ, Epson, Hitachi, HP, Maginon, Minolta, Pentax, Ricoh, Samsung, Sanyo, SeaLife, Sony, Supra and Vivitar.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | MakerNoteVersion | undef |
> 0x0001 | MinoltaCameraSettingsOld | - | --> Minolta CameraSettings Tags
> 0x0003 | MinoltaCameraSettings | - | --> Minolta CameraSettings Tags
> 0x0040 | CompressedImageSize | int32u |
> 0x0081 | PreviewImageData | no |
> 0x0088 | PreviewImageStart | no |
> 0x0089 | PreviewImageLength | no |
> 0x0100 | ThumbnailImage | undef |
> 0x0104 | BodyFirmwareVersion | string |
> 0x0200 | SpecialMode | int32u[3]~ | (3 numbers: 1. Shooting mode: 0=Normal, 2=Fast, 3=Panorama; 2. Sequence Number; 3. Panorama Direction: 1=Left-right, 2=Right-left, 3=Bottom-Top, 4=Top-Bottom)
> 0x0201 | Quality | int16u~ | (Quality values are decoded based on the CameraType tag. All types represent SQ, HQ and SHQ as sequential integers, but in general SX-type cameras start with a value of 0 for SQ while others start with 1)
> 0x0202 | Macro | int16u | 0 = Off 1 = On 2 = Super Macro
> 0x0203 | BWMode | int16u | 0 = Off 1 = On 6 = (none)
> 0x0204 | DigitalZoom | rational64u |
> 0x0205 | FocalPlaneDiagonal | rational64u |
> 0x0206 | LensDistortionParams | int16s[6] |
> 0x0207 | CameraType | string | --> Olympus CameraType Values
> 0x0208 | TextInfo | - | --> Olympus TextInfo Tags
> 0x0209 | CameraID | string |
> 0x020b | EpsonImageWidth | int32u |
> 0x020c | EpsonImageHeight | int32u |
> 0x020d | EpsonSoftware | string |
> 0x0280 | PreviewImage | int8u | (found in ERF and JPG images from some Epson models)
> 0x0300 | PreCaptureFrames | int16u |
> 0x0301 | WhiteBoard | int16u |
> 0x0302 | OneTouchWB | int16u | 0 = Off 1 = On 2 = On (Preset)
> 0x0303 | WhiteBalanceBracket | int16u |
> 0x0304 | WhiteBalanceBias | int16u |
> 0x0400 | SensorArea | undef[8] | (found in Epson ERF images)
> 0x0401 | BlackLevel | int32u[4] | (found in Epson ERF images)
> 0x0403 | SceneMode | int16u |
> 0 = Normal 1 = Standard 2 = Auto 3 = Intelligent Auto 4 = Portrait 5 = Landscape+Portrait 6 = Landscape 7 = Night Scene 8 = Night+Portrait 9 = Sport 10 = Self Portrait 11 = Indoor 12 = Beach & Snow 13 = Beach 14 = Snow 15 = Self Portrait+Self Timer 16 = Sunset 17 = Cuisine 18 = Documents 19 = Candle |  | 20 = Fireworks 21 = Available Light 22 = Vivid 23 = Underwater Wide1 24 = Underwater Macro 25 = Museum 26 = Behind Glass 27 = Auction 28 = Shoot & Select1 29 = Shoot & Select2 30 = Underwater Wide2 31 = Digital Image Stabilization 32 = Face Portrait 33 = Pet 34 = Smile Shot 35 = Quick Shutter 43 = Hand-held Starlight 100 = Panorama 101 = Magic Filter 103 = HDR
> 0x0404 | SerialNumber | string |
> 0x0405 | Firmware | string |
> 0x0e00 | PrintIM | - | --> PrintIM Tags
> 0x0f00 | DataDump | no |
> 0x0f01 | DataDump2 | no |
> 0x0f04 | ZoomedPreviewStart | int32u* |
> 0x0f05 | ZoomedPreviewLength | int32u* |
> 0x0f06 | ZoomedPreviewSize | int16u[2] |
> 0x1000 | ShutterSpeedValue | rational64s |
> 0x1001 | ISOValue | rational64s |
> 0x1002 | ApertureValue | rational64s |
> 0x1003 | BrightnessValue | rational64s |
> 0x1004 | FlashMode | int16u | 2 = On 3 = Off
> 0x1005 | FlashDevice | int16u | 0 = None 1 = Internal 4 = External 5 = Internal + External
> 0x1006 | ExposureCompensation | rational64s |
> 0x1007 | SensorTemperature | int16s |
> 0x1008 | LensTemperature | int16s |
> 0x1009 | LightCondition | int16u |
> 0x100a | FocusRange | int16u | 0 = Normal 1 = Macro
> 0x100b | FocusMode | int16u | 0 = Auto 1 = Manual
> 0x100c | ManualFocusDistance | rational64u |
> 0x100d | ZoomStepCount | int16u |
> 0x100e | FocusStepCount | int16u |
> 0x100f | Sharpness | int16u | 0 = Normal 1 = Hard 2 = Soft
> 0x1010 | FlashChargeLevel | int16u |
> 0x1011 | ColorMatrix | int16u[9] |
> 0x1012 | BlackLevel | int16u[4] |
> 0x1013 | ColorTemperatureBG? | int16u |
> 0x1014 | ColorTemperatureRG? | int16u |
> 0x1015 | WBMode | int16u[2] |
> 1 = Auto '1 0' = Auto '1 2' = Auto (2) '1 4' = Auto (4) '2 2' = 3000 Kelvin '2 3' = 3700 Kelvin |  | '2 4' = 4000 Kelvin '2 5' = 4500 Kelvin '2 6' = 5500 Kelvin '2 7' = 6500 Kelvin '2 8' = 7500 Kelvin '3 0' = One-touch
> 0x1017 | RedBalance | int16u[2] |
> 0x1018 | BlueBalance | int16u[2] |
> 0x1019 | ColorMatrixNumber | int16u |
> 0x101a | SerialNumber | string |
> 0x101b | ExternalFlashAE1_0? | int32u |
> 0x101c | ExternalFlashAE2_0? | int32u |
> 0x101d | InternalFlashAE1_0? | int32u |
> 0x101e | InternalFlashAE2_0? | int32u |
> 0x101f | ExternalFlashAE1? | int32u |
> 0x1020 | ExternalFlashAE2? | int32u |
> 0x1021 | InternalFlashAE1? | int32u |
> 0x1022 | InternalFlashAE2? | int32u |
> 0x1023 | FlashExposureComp | rational64s |
> 0x1024 | InternalFlashTable | int16u |
> 0x1025 | ExternalFlashGValue | rational64s |
> 0x1026 | ExternalFlashBounce | int16u | 0 = No 1 = Yes
> 0x1027 | ExternalFlashZoom | int16u |
> 0x1028 | ExternalFlashMode | int16u |
> 0x1029 | Contrast | int16u | 0 = High 1 = Normal 2 = Low
> 0x102a | SharpnessFactor | int16u |
> 0x102b | ColorControl | int16u[6] |
> 0x102c | ValidBits | int16u[2] |
> 0x102d | CoringFilter | int16u |
> 0x102e | OlympusImageWidth | int32u |
> 0x102f | OlympusImageHeight | int32u |
> 0x1030 | SceneDetect | int16u |
> 0x1031 | SceneArea? | int32u[8] |
> 0x1033 | SceneDetectData? | int32u[720] |
> 0x1034 | CompressionRatio | rational64u |
> 0x1035 | PreviewImageValid | int32u | 0 = No 1 = Yes
> 0x1036 | PreviewImageStart | int32u* |
> 0x1037 | PreviewImageLength | int32u* |
> 0x1038 | AFResult | int16u |
> 0x1039 | CCDScanMode | int16u | 0 = Interlaced 1 = Progressive
> 0x103a | NoiseReduction | int16u | 0 = Off 1 = On
> 0x103b | FocusStepInfinity | int16u |
> 0x103c | FocusStepNear | int16u |
> 0x103d | LightValueCenter | rational64s |
> 0x103e | LightValuePeriphery | rational64s |
> 0x103f | FieldCount? | int16u |
> 0x2010 | Equipment EquipmentIFD | - - | --> Olympus Equipment Tags --> Olympus Equipment Tags
> 0x2020 | CameraSettings CameraSettingsIFD | - - | --> Olympus CameraSettings Tags --> Olympus CameraSettings Tags
> 0x2030 | RawDevelopment RawDevelopmentIFD | - - | --> Olympus RawDevelopment Tags --> Olympus RawDevelopment Tags
> 0x2031 | RawDev2 RawDev2IFD | - - | --> Olympus RawDevelopment2 Tags --> Olympus RawDevelopment2 Tags
> 0x2040 | ImageProcessing ImageProcessingIFD | - - | --> Olympus ImageProcessing Tags --> Olympus ImageProcessing Tags
> 0x2050 | FocusInfo FocusInfoIFD CameraParameters | - - undef | --> Olympus FocusInfo Tags --> Olympus FocusInfo Tags
> 0x2100 | Olympus2100 Olympus2100IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2200 | Olympus2200 Olympus2200IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2300 | Olympus2300 Olympus2300IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2400 | Olympus2400 Olympus2400IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2500 | Olympus2500 Olympus2500IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2600 | Olympus2600 Olympus2600IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2700 | Olympus2700 Olympus2700IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2800 | Olympus2800 Olympus2800IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x2900 | Olympus2900 Olympus2900IFD | - - | --> Olympus FE Tags --> Olympus FE Tags
> 0x3000 | RawInfo RawInfoIFD | - - | --> Olympus RawInfo Tags --> Olympus RawInfo Tags
> 0x4000 | MainInfo MainInfoIFD | - - | --> Olympus Tags --> Olympus Tags
> 0x5000 | UnknownInfo UnknownInfoIFD | - - | --> Olympus UnknownInfo Tags --> Olympus UnknownInfo Tags

## Olympus CameraType Values

These values are currently decoded only for Olympus models. Models with Olympus-style maker notes from other brands such as Acer, BenQ, Hitachi, HP, Premier, Konica-Minolta, Maginon, Ricoh, Rollei, SeaLife, Sony, Supra, Vivitar are not listed.

> Value | CameraType | Value | CameraType | Value | CameraType
> --- | --- | --- | --- | --- | ---
> 'D4028' | = X-2,C-50Z | 'D4402' | = uT6010,ST6010 | 'S0018' | = E-520
> 'D4029' | = E-20,E-20N,E-20P | 'D4406' | = u7010,S7010 / u7020,S7020 | 'S0019' | = E-P1
> 'D4034' | = C720UZ | 'D4407' | = FE4010,X930 | 'S0023' | = E-620
> 'D4040' | = E-1 | 'D4408' | = X560WP | 'S0026' | = E-P2
> 'D4041' | = E-300 | 'D4409' | = FE26,X21 | 'S0027' | = E-PL1
> 'D4083' | = C2Z,D520Z,C220Z | 'D4410' | = FE4000,X920,X925 | 'S0029' | = E-450
> 'D4106' | = u20D,S400D,u400D | 'D4411' | = FE46,X41,X42 | 'S0030' | = E-600
> 'D4120' | = X-1 | 'D4412' | = FE5020,X935 | 'S0032' | = E-P3
> 'D4122' | = u10D,S300D,u300D | 'D4413' | = uTough-3000 | 'S0033' | = E-5
> 'D4125' | = AZ-1 | 'D4414' | = StylusTough-6020 | 'S0034' | = E-PL2
> 'D4141' | = C150,D390 | 'D4415' | = StylusTough-8010 | 'S0036' | = E-M5
> 'D4193' | = C-5000Z | 'D4417' | = u5010,S5010 | 'S0038' | = E-PL3
> 'D4194' | = X-3,C-60Z | 'D4418' | = u7040,S7040 | 'S0039' | = E-PM1
> 'D4199' | = u30D,S410D,u410D | 'D4419' | = u9010,S9010 | 'S0040' | = E-PL1s
> 'D4205' | = X450,D535Z,C370Z | 'D4423' | = FE4040 | 'S0042' | = E-PL5
> 'D4210' | = C160,D395 | 'D4424' | = FE47,X43 | 'S0043' | = E-PM2
> 'D4211' | = C725UZ | 'D4426' | = FE4030,X950 | 'S0044' | = E-P5
> 'D4213' | = FerrariMODEL2003 | 'D4428' | = FE5030,X965,X960 | 'S0045' | = E-PL6
> 'D4216' | = u15D | 'D4430' | = u7030,S7030 | 'S0046' | = E-PL7
> 'D4217' | = u25D | 'D4432' | = SP600UZ | 'S0047' | = E-M1
> 'D4220' | = u-miniD,Stylus V | 'D4434' | = SP800UZ | 'S0051' | = E-M10
> 'D4221' | = u40D,S500,uD500 | 'D4439' | = FE4020,X940 | 'S0052' | = E-M5MarkII
> 'D4231' | = FerrariMODEL2004 | 'D4442' | = FE5035 | 'S0059' | = E-M10MarkII
> 'D4240' | = X500,D590Z,C470Z | 'D4448' | = FE4050,X970 | 'S0061' | = PEN-F
> 'D4244' | = uD800,S800 | 'D4450' | = FE5050,X985 | 'S0065' | = E-PL8
> 'D4256' | = u720SW,S720SW | 'D4454' | = u-7050 | 'S0067' | = E-M1MarkII
> 'D4261' | = X600,D630,FE5500 | 'D4464' | = T10,X27 | 'S0068' | = E-M10MarkIII
> 'D4262' | = uD600,S600 | 'D4470' | = FE5040,X980 | 'S0076' | = E-PL9
> 'D4301' | = u810/S810 | 'D4472' | = TG-310 | 'S0080' | = E-M1X
> 'D4302' | = u710,S710 | 'D4474' | = TG-610 | 'S0085' | = E-PL10
> 'D4303' | = u700,S700 | 'D4476' | = TG-810 | 'S0088' | = E-M10MarkIV
> 'D4304' | = FE100,X710 | 'D4478' | = VG145,VG140,D715 | 'S0089' | = E-M5MarkIII
> 'D4305' | = FE110,X705 | 'D4479' | = VG130,D710 | 'S0092' | = E-M1MarkIII
> 'D4310' | = FE-130,X-720 | 'D4480' | = VG120,D705 | 'S0093' | = E-P7
> 'D4311' | = FE-140,X-725 | 'D4482' | = VR310,D720 | 'S0095' | = OM-1
> 'D4312' | = FE150,X730 | 'D4484' | = VR320,D725 | 'S0101' | = OM-5
> 'D4313' | = FE160,X735 | 'D4486' | = VR330,D730 | 'S0121' | = OM-1MarkII
> 'D4314' | = u740,S740 | 'D4488' | = VG110,D700 | 'SR45' | = D220
> 'D4315' | = u750,S750 | 'D4490' | = SP-610UZ | 'SR55' | = D320L
> 'D4316' | = u730/S730 | 'D4492' | = SZ-10 | 'SR83' | = D340L
> 'D4317' | = FE115,X715 | 'D4494' | = SZ-20 | 'SR85' | = C830L,D340R
> 'D4321' | = SP550UZ | 'D4496' | = SZ-30MR | 'SR852' | = C860L,D360L
> 'D4322' | = SP510UZ | 'D4498' | = SP-810UZ | 'SR872' | = C900Z,D400Z
> 'D4324' | = FE170,X760 | 'D4500' | = SZ-11 | 'SR874' | = C960Z,D460Z
> 'D4326' | = FE200 | 'D4504' | = TG-615 | 'SR951' | = C2000Z
> 'D4327' | = FE190/X750 | 'D4508' | = TG-620 | 'SR952' | = C21
> 'D4328' | = u760,S760 | 'D4510' | = TG-820 | 'SR953' | = C21T.commu
> 'D4330' | = FE180/X745 | 'D4512' | = TG-1 | 'SR954' | = C2020Z
> 'D4331' | = u1000/S1000 | 'D4516' | = SH-21 | 'SR955' | = C990Z,D490Z
> 'D4332' | = u770SW,S770SW | 'D4519' | = SZ-14 | 'SR956' | = C211Z
> 'D4333' | = FE240/X795 | 'D4520' | = SZ-31MR | 'SR959' | = C990ZS,D490Z
> 'D4334' | = FE210,X775 | 'D4521' | = SH-25MR | 'SR95A' | = C2100UZ
> 'D4336' | = FE230/X790 | 'D4523' | = SP-720UZ | 'SR971' | = C100,D370
> 'D4337' | = FE220,X785 | 'D4529' | = VG170 | 'SR973' | = C2,D230
> 'D4338' | = u725SW,S725SW | 'D4530' | = VH210 | 'SX151' | = E100RS
> 'D4339' | = FE250/X800 | 'D4531' | = XZ-2 | 'SX351' | = C3000Z / C3030Z
> 'D4341' | = u780,S780 | 'D4535' | = SP-620UZ | 'SX354' | = C3040Z
> 'D4343' | = u790SW,S790SW | 'D4536' | = TG-320 | 'SX355' | = C2040Z
> 'D4344' | = u1020,S1020 | 'D4537' | = VR340,D750 | 'SX357' | = C700UZ
> 'D4346' | = FE15,X10 | 'D4538' | = VG160,X990,D745 | 'SX358' | = C200Z,D510Z
> 'D4348' | = FE280,X820,C520 | 'D4541' | = SZ-12 | 'SX374' | = C3100Z,C3020Z
> 'D4349' | = FE300,X830 | 'D4545' | = VH410 | 'SX552' | = C4040Z
> 'D4350' | = u820,S820 | 'D4546' | = XZ-10 | 'SX553' | = C40Z,D40Z
> 'D4351' | = u1200,S1200 | 'D4547' | = TG-2 | 'SX556' | = C730UZ
> 'D4352' | = FE270,X815,C510 | 'D4548' | = TG-830 | 'SX558' | = C5050Z
> 'D4353' | = u795SW,S795SW | 'D4549' | = TG-630 | 'SX571' | = C120,D380
> 'D4354' | = u1030SW,S1030SW | 'D4550' | = SH-50 | 'SX574' | = C300Z,D550Z
> 'D4355' | = SP560UZ | 'D4553' | = SZ-16,DZ-105 | 'SX575' | = C4100Z,C4000Z
> 'D4356' | = u1010,S1010 | 'D4562' | = SP-820UZ | 'SX751' | = X200,D560Z,C350Z
> 'D4357' | = u830,S830 | 'D4566' | = SZ-15 | 'SX752' | = X300,D565Z,C450Z
> 'D4359' | = u840,S840 | 'D4572' | = STYLUS1 | 'SX753' | = C750UZ
> 'D4360' | = FE350WIDE,X865 | 'D4574' | = TG-3 | 'SX754' | = C740UZ
> 'D4361' | = u850SW,S850SW | 'D4575' | = TG-850 | 'SX755' | = C755UZ
> 'D4362' | = FE340,X855,C560 | 'D4579' | = SP-100EE | 'SX756' | = C5060WZ
> 'D4363' | = FE320,X835,C540 | 'D4580' | = SH-60 | 'SX757' | = C8080WZ
> 'D4364' | = SP570UZ | 'D4581' | = SH-1 | 'SX758' | = X350,D575Z,C360Z
> 'D4366' | = FE330,X845,C550 | 'D4582' | = TG-835 | 'SX759' | = X400,D580Z,C460Z
> 'D4368' | = FE310,X840,C530 | 'D4585' | = SH-2 / SH-3 | 'SX75A' | = AZ-2ZOOM
> 'D4370' | = u1050SW,S1050SW | 'D4586' | = TG-4 | 'SX75B' | = D595Z,C500Z
> 'D4371' | = u1060,S1060 | 'D4587' | = TG-860 | 'SX75C' | = X550,D545Z,C480Z
> 'D4372' | = FE370,X880,C575 | 'D4590' | = TG-TRACKER | 'SX75D' | = IR-300
> 'D4374' | = SP565UZ | 'D4591' | = TG-870 | 'SX75F' | = C55Z,C5500Z
> 'D4377' | = u1040,S1040 | 'D4593' | = TG-5 | 'SX75G' | = C170,D425
> 'D4378' | = FE360,X875,C570 | 'D4603' | = TG-6 | 'SX75J' | = C180,D435
> 'D4379' | = FE20,X15,C25 | 'D4605' | = TG-7 | 'SX771' | = C760UZ
> 'D4380' | = uT6000,ST6000 | 'D4809' | = C2500L | 'SX772' | = C770UZ
> 'D4381' | = uT8000,ST8000 | 'D4842' | = E-10 | 'SX773' | = C745UZ
> 'D4382' | = u9000,S9000 | 'D4856' | = C-1 | 'SX774' | = X250,D560Z,C350Z
> 'D4384' | = SP590UZ | 'D4857' | = C-1Z,D-150Z | 'SX775' | = X100,D540Z,C310Z
> 'D4385' | = FE3010,X895 | 'DCHC' | = D500L | 'SX776' | = C460ZdelSol
> 'D4386' | = FE3000,X890 | 'DCHT' | = D600L / D620L | 'SX777' | = C765UZ
> 'D4387' | = FE35,X30 | 'K0055' | = AIR-A01 | 'SX77A' | = D555Z,C315Z
> 'D4388' | = u550WP,S550WP | 'S0003' | = E-330 | 'SX851' | = C7070WZ
> 'D4390' | = FE5000,X905 | 'S0004' | = E-500 | 'SX852' | = C70Z,C7000Z
> 'D4391' | = u5000 | 'S0009' | = E-400 | 'SX853' | = SP500UZ
> 'D4392' | = u7000,S7000 | 'S0010' | = E-510 | 'SX854' | = SP310
> 'D4396' | = FE5010,X915 | 'S0011' | = E-3 | 'SX855' | = SP350
> 'D4397' | = FE25,X20 | 'S0013' | = E-410 | 'SX873' | = SP320
> 'D4398' | = FE45,X40 | 'S0016' | = E-420 | 'SX875' | = FE180/X745
> 'D4401' | = XZ-1 | 'S0017' | = E-30 | 'SX876' | = FE190/X750

## Olympus TextInfo Tags

This information is in text format (similar to APP12 information, but with spaces instead of linefeeds). Below are tags which have been observed, but any information found here will be extracted, even if the tag is not listed.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 'Resolution' | Resolution | no |
> 'Type' | CameraType | no | --> Olympus CameraType Values

## Olympus Equipment Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | EquipmentVersion | undef[4] |
> 0x0100 | CameraType2 | string[6] | --> Olympus CameraType Values
> 0x0101 | SerialNumber | string[32] |
> 0x0102 | InternalSerialNumber | string[32] | (16 digits: 0-3=model, 4=year, 5-6=month, 8-12=unit number)
> 0x0103 | FocalPlaneDiagonal | rational64u |
> 0x0104 | BodyFirmwareVersion | int32u |
> 0x0201 | LensType | int8u[6] | --> Olympus LensType Values (6 numbers: 1. Make, 2. Unknown, 3. Model, 4. Sub-model, 5-6. Unknown. Only the Make, Model and Sub-model are used to identify the lens type)
> 0x0202 | LensSerialNumber | string[32] |
> 0x0203 | LensModel | string |
> 0x0204 | LensFirmwareVersion | int32u |
> 0x0205 | MaxApertureAtMinFocal | int16u |
> 0x0206 | MaxApertureAtMaxFocal | int16u |
> 0x0207 | MinFocalLength | int16u |
> 0x0208 | MaxFocalLength | int16u |
> 0x020a | MaxAperture | int16u |
> 0x020b | LensProperties | int16u |
> 0x0301 | Extender | int8u[6] | (6 numbers: 1. Make, 2. Unknown, 3. Model, 4. Sub-model, 5-6. Unknown. Only the Make and Model are used to identify the extender) '0 00' = None '0 04' = Olympus Zuiko Digital EC-14 1.4x Teleconverter '0 08' = Olympus EX-25 Extension Tube '0 10' = Olympus Zuiko Digital EC-20 2.0x Teleconverter
> 0x0302 | ExtenderSerialNumber | string[32] |
> 0x0303 | ExtenderModel | string |
> 0x0304 | ExtenderFirmwareVersion | int32u |
> 0x0403 | ConversionLens | string |
> 0x1000 | FlashType | int16u | 0 = None 2 = Simple E-System 3 = E-System 4 = E-System (body powered)
> 0x1001 | FlashModel | int16u |
> 0 = None 1 = FL-20 2 = FL-50 3 = RF-11 4 = TF-22 5 = FL-36 |  | 6 = FL-50R 7 = FL-36R 9 = FL-14 11 = FL-600R 13 = FL-LM3 15 = FL-900R
> 0x1002 | FlashFirmwareVersion | int32u |
> 0x1003 | FlashSerialNumber | string[32] |

## Olympus LensType Values

The numerical values below are given in hexadecimal. (Prior to ExifTool 9.15 these were in decimal.)

> Value | LensType
> --- | ---
> '0 00 00' | = None
> '0 01 00' | = Olympus Zuiko Digital ED 50mm F2.0 Macro
> '0 01 01' | = Olympus Zuiko Digital 40-150mm F3.5-4.5
> '0 01 10' | = Olympus M.Zuiko Digital ED 14-42mm F3.5-5.6
> '0 02 00' | = Olympus Zuiko Digital ED 150mm F2.0
> '0 02 10' | = Olympus M.Zuiko Digital 17mm F2.8 Pancake
> '0 03 00' | = Olympus Zuiko Digital ED 300mm F2.8
> '0 03 10' | = Olympus M.Zuiko Digital ED 14-150mm F4.0-5.6 [II]
> '0 04 10' | = Olympus M.Zuiko Digital ED 9-18mm F4.0-5.6
> '0 05 00' | = Olympus Zuiko Digital 14-54mm F2.8-3.5
> '0 05 01' | = Olympus Zuiko Digital Pro ED 90-250mm F2.8
> '0 05 10' | = Olympus M.Zuiko Digital ED 14-42mm F3.5-5.6 L
> '0 06 00' | = Olympus Zuiko Digital ED 50-200mm F2.8-3.5
> '0 06 01' | = Olympus Zuiko Digital ED 8mm F3.5 Fisheye
> '0 06 10' | = Olympus M.Zuiko Digital ED 40-150mm F4.0-5.6
> '0 07 00' | = Olympus Zuiko Digital 11-22mm F2.8-3.5
> '0 07 01' | = Olympus Zuiko Digital 18-180mm F3.5-6.3
> '0 07 10' | = Olympus M.Zuiko Digital ED 12mm F2.0
> '0 08 01' | = Olympus Zuiko Digital 70-300mm F4.0-5.6
> '0 08 10' | = Olympus M.Zuiko Digital ED 75-300mm F4.8-6.7
> '0 09 10' | = Olympus M.Zuiko Digital 14-42mm F3.5-5.6 II
> '0 10 01' | = Kenko Tokina Reflex 300mm F6.3 MF Macro
> '0 10 10' | = Olympus M.Zuiko Digital ED 12-50mm F3.5-6.3 EZ
> '0 11 10' | = Olympus M.Zuiko Digital 45mm F1.8
> '0 12 10' | = Olympus M.Zuiko Digital ED 60mm F2.8 Macro
> '0 13 10' | = Olympus M.Zuiko Digital 14-42mm F3.5-5.6 II R
> '0 14 10' | = Olympus M.Zuiko Digital ED 40-150mm F4.0-5.6 R
> '0 15 00' | = Olympus Zuiko Digital ED 7-14mm F4.0
> '0 15 10' | = Olympus M.Zuiko Digital ED 75mm F1.8
> '0 16 10' | = Olympus M.Zuiko Digital 17mm F1.8
> '0 17 00' | = Olympus Zuiko Digital Pro ED 35-100mm F2.0
> '0 18 00' | = Olympus Zuiko Digital 14-45mm F3.5-5.6
> '0 18 10' | = Olympus M.Zuiko Digital ED 75-300mm F4.8-6.7 II
> '0 19 10' | = Olympus M.Zuiko Digital ED 12-40mm F2.8 Pro
> '0 20 00' | = Olympus Zuiko Digital 35mm F3.5 Macro
> '0 20 10' | = Olympus M.Zuiko Digital ED 40-150mm F2.8 Pro
> '0 21 10' | = Olympus M.Zuiko Digital ED 14-42mm F3.5-5.6 EZ
> '0 22 00' | = Olympus Zuiko Digital 17.5-45mm F3.5-5.6
> '0 22 10' | = Olympus M.Zuiko Digital 25mm F1.8
> '0 23 00' | = Olympus Zuiko Digital ED 14-42mm F3.5-5.6
> '0 23 10' | = Olympus M.Zuiko Digital ED 7-14mm F2.8 Pro
> '0 24 00' | = Olympus Zuiko Digital ED 40-150mm F4.0-5.6
> '0 24 10' | = Olympus M.Zuiko Digital ED 300mm F4.0 IS Pro
> '0 25 10' | = Olympus M.Zuiko Digital ED 8mm F1.8 Fisheye Pro
> '0 26 10' | = Olympus M.Zuiko Digital ED 12-100mm F4.0 IS Pro
> '0 27 10' | = Olympus M.Zuiko Digital ED 30mm F3.5 Macro
> '0 28 10' | = Olympus M.Zuiko Digital ED 25mm F1.2 Pro
> '0 29 10' | = Olympus M.Zuiko Digital ED 17mm F1.2 Pro
> '0 30 00' | = Olympus Zuiko Digital ED 50-200mm F2.8-3.5 SWD
> '0 30 10' | = Olympus M.Zuiko Digital ED 45mm F1.2 Pro
> '0 31 00' | = Olympus Zuiko Digital ED 12-60mm F2.8-4.0 SWD
> '0 32 00' | = Olympus Zuiko Digital ED 14-35mm F2.0 SWD
> '0 32 10' | = Olympus M.Zuiko Digital ED 12-200mm F3.5-6.3
> '0 33 00' | = Olympus Zuiko Digital 25mm F2.8
> '0 33 10' | = Olympus M.Zuiko Digital 150-400mm F4.5 TC1.25x IS Pro
> '0 34 00' | = Olympus Zuiko Digital ED 9-18mm F4.0-5.6
> '0 34 10' | = Olympus M.Zuiko Digital ED 12-45mm F4.0 Pro
> '0 35 00' | = Olympus Zuiko Digital 14-54mm F2.8-3.5 II
> '0 35 10' | = Olympus M.Zuiko 100-400mm F5.0-6.3
> '0 36 10' | = Olympus M.Zuiko Digital ED 8-25mm F4 Pro
> '0 37 10' | = Olympus M.Zuiko Digital ED 40-150mm F4.0 Pro
> '0 39 10' | = Olympus M.Zuiko Digital ED 90mm F3.5 Macro IS Pro
> '0 40 10' | = Olympus M.Zuiko Digital ED 150-600mm F5.0-6.3
> '1 01 00' | = Sigma 18-50mm F3.5-5.6 DC
> '1 01 10' | = Sigma 30mm F2.8 EX DN
> '1 02 00' | = Sigma 55-200mm F4.0-5.6 DC
> '1 02 10' | = Sigma 19mm F2.8 EX DN
> '1 03 00' | = Sigma 18-125mm F3.5-5.6 DC
> '1 03 10' | = Sigma 30mm F2.8 DN | A
> '1 04 00' | = Sigma 18-125mm F3.5-5.6 DC
> '1 04 10' | = Sigma 19mm F2.8 DN | A
> '1 05 00' | = Sigma 30mm F1.4 EX DC HSM
> '1 05 10' | = Sigma 60mm F2.8 DN | A
> '1 06 00' | = Sigma APO 50-500mm F4.0-6.3 EX DG HSM
> '1 06 10' | = Sigma 30mm F1.4 DC DN | C
> '1 07 00' | = Sigma Macro 105mm F2.8 EX DG
> '1 07 10' | = Sigma 16mm F1.4 DC DN | C (017)
> '1 08 00' | = Sigma APO Macro 150mm F2.8 EX DG HSM
> '1 09 00' | = Sigma 18-50mm F2.8 EX DC Macro
> '1 10 00' | = Sigma 24mm F1.8 EX DG Aspherical Macro
> '1 11 00' | = Sigma APO 135-400mm F4.5-5.6 DG
> '1 12 00' | = Sigma APO 300-800mm F5.6 EX DG HSM
> '1 13 00' | = Sigma 30mm F1.4 EX DC HSM
> '1 14 00' | = Sigma APO 50-500mm F4.0-6.3 EX DG HSM
> '1 15 00' | = Sigma 10-20mm F4.0-5.6 EX DC HSM
> '1 16 00' | = Sigma APO 70-200mm F2.8 II EX DG Macro HSM
> '1 17 00' | = Sigma 50mm F1.4 EX DG HSM
> '2 01 00' | = Leica D Vario Elmarit 14-50mm F2.8-3.5 Asph.
> '2 01 10' | = Lumix G Vario 14-45mm F3.5-5.6 Asph. Mega OIS
> '2 02 00' | = Leica D Summilux 25mm F1.4 Asph.
> '2 02 10' | = Lumix G Vario 45-200mm F4.0-5.6 Mega OIS
> '2 03 00' | = Leica D Vario Elmar 14-50mm F3.8-5.6 Asph. Mega OIS
> '2 03 01' | = Leica D Vario Elmar 14-50mm F3.8-5.6 Asph.
> '2 03 10' | = Lumix G Vario HD 14-140mm F4.0-5.8 Asph. Mega OIS
> '2 04 00' | = Leica D Vario Elmar 14-150mm F3.5-5.6
> '2 04 10' | = Lumix G Vario 7-14mm F4.0 Asph.
> '2 05 10' | = Lumix G 20mm F1.7 Asph.
> '2 06 10' | = Leica DG Macro-Elmarit 45mm F2.8 Asph. Mega OIS
> '2 07 10' | = Lumix G Vario 14-42mm F3.5-5.6 Asph. Mega OIS
> '2 08 10' | = Lumix G Fisheye 8mm F3.5
> '2 09 10' | = Lumix G Vario 100-300mm F4.0-5.6 Mega OIS
> '2 10 10' | = Lumix G 14mm F2.5 Asph.
> '2 11 10' | = Lumix G 12.5mm F12 3D
> '2 12 10' | = Leica DG Summilux 25mm F1.4 Asph.
> '2 13 10' | = Lumix G X Vario PZ 45-175mm F4.0-5.6 Asph. Power OIS
> '2 14 10' | = Lumix G X Vario PZ 14-42mm F3.5-5.6 Asph. Power OIS
> '2 15 10' | = Lumix G X Vario 12-35mm F2.8 Asph. Power OIS
> '2 16 10' | = Lumix G Vario 45-150mm F4.0-5.6 Asph. Mega OIS
> '2 17 10' | = Lumix G X Vario 35-100mm F2.8 Power OIS
> '2 18 10' | = Lumix G Vario 14-42mm F3.5-5.6 II Asph. Mega OIS
> '2 19 10' | = Lumix G Vario 14-140mm F3.5-5.6 Asph. Power OIS
> '2 20 10' | = Lumix G Vario 12-32mm F3.5-5.6 Asph. Mega OIS
> '2 21 10' | = Leica DG Nocticron 42.5mm F1.2 Asph. Power OIS
> '2 22 10' | = Leica DG Summilux 15mm F1.7 Asph.
> '2 23 10' | = Lumix G Vario 35-100mm F4.0-5.6 Asph. Mega OIS
> '2 24 10' | = Lumix G Macro 30mm F2.8 Asph. Mega OIS
> '2 25 10' | = Lumix G 42.5mm F1.7 Asph. Power OIS
> '2 26 10' | = Lumix G 25mm F1.7 Asph.
> '2 27 10' | = Leica DG Vario-Elmar 100-400mm F4.0-6.3 Asph. Power OIS
> '2 28 10' | = Lumix G Vario 12-60mm F3.5-5.6 Asph. Power OIS
> '2 29 10' | = Leica DG Summilux 12mm F1.4 Asph.
> '2 30 10' | = Leica DG Vario-Elmarit 12-60mm F2.8-4 Asph. Power OIS
> '2 31 10' | = Lumix G Vario 45-200mm F4.0-5.6 II
> '2 32 10' | = Lumix G Vario 100-300mm F4.0-5.6 II
> '2 33 10' | = Lumix G X Vario 12-35mm F2.8 II Asph. Power OIS
> '2 34 10' | = Lumix G Vario 35-100mm F2.8 II
> '2 35 10' | = Leica DG Vario-Elmarit 8-18mm F2.8-4 Asph.
> '2 36 10' | = Leica DG Elmarit 200mm F2.8 Power OIS
> '2 37 10' | = Leica DG Vario-Elmarit 50-200mm F2.8-4 Asph. Power OIS
> '2 38 10' | = Leica DG Vario-Summilux 10-25mm F1.7 Asph.
> '2 39 10' | = Leica DG Summilux 25mm F1.4 II Asph.
> '2 40 10' | = Leica DG Vario-Summilux 25-50mm F1.7 Asph.
> '2 41 10' | = Leica DG Summilux 9mm F1.7 Asph.
> '3 01 00' | = Leica D Vario Elmarit 14-50mm F2.8-3.5 Asph.
> '3 02 00' | = Leica D Summilux 25mm F1.4 Asph.
> '5 01 10' | = Tamron 14-150mm F3.5-5.8 Di III
> '24 01 10' | = Venus Optics Laowa 50mm F2.8 2x Macro
> 'f7 03 10' | = LAOWA C&D-Dreamer MFT 7.5mm F2.0

## Olympus CameraSettings Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | CameraSettingsVersion | undef[4] |
> 0x0100 | PreviewImageValid | int32u | 0 = No 1 = Yes
> 0x0101 | PreviewImageStart | int32u* |
> 0x0102 | PreviewImageLength | int32u* |
> 0x0200 | ExposureMode | int16u | 1 = Manual 2 = Program 3 = Aperture-priority AE 4 = Shutter speed priority AE 5 = Program-shift
> 0x0201 | AELock | int16u | 0 = Off 1 = On
> 0x0202 | MeteringMode | int16u |
> 2 = Center-weighted average 3 = Spot 5 = ESP 261 = Pattern+AF 515 = Spot+Highlight control 1027 = Spot+Shadow control
> 0x0203 | ExposureShift | rational64s |
> 0x0204 | NDFilter | yes | 0 = Off 1 = On
> 0x0300 | MacroMode | int16u | 0 = Off 1 = On 2 = Super Macro
> 0x0301 | FocusMode | int16u[n] | (1 or 2 values) [Value 0]
> 0 = Single AF 1 = Sequential shooting AF 2 = Continuous AF 3 = Multi AF 4 = Face Detect 10 = MF
> [Value 1]
> 0x0 = (none) Bit 0 = S-AF Bit 2 = C-AF Bit 4 = MF Bit 5 = Face Detect Bit 6 = Imager AF Bit 7 = Live View Magnification Frame Bit 8 = AF sensor Bit 9 = Starry Sky AF
> 0x0302 | FocusProcess | int16u[n] | (1 or 2 values) [Value 0] 0 = AF Not Used 1 = AF Used
> 0x0303 | AFSearch | int16u | 0 = Not Ready 1 = Ready
> 0x0304 | AFAreas | int32u[64]~ | (coordinates range from 0 to 255)
> 0x0305 | AFPointSelected | rational64s[5] | (coordinates expressed as a percent)
> 0x0306 | AFFineTune | int8u | 0 = Off 1 = On
> 0x0307 | AFFineTuneAdj | int16s[3] |
> 0x0308 | FocusBracketStepSize | int8u |
> 0x0309 | AISubjectTrackingMode | int16u | [Value 0]
> 0 = Off 1 = Motorsports 2 = Airplanes |  | 3 = Trains 4 = Birds 5 = Dogs & Cats
> [Value 1] 0 = Object Not Found 1 = Object Found
> 0x0400 | FlashMode | int16u |
> 0x0 = Off Bit 0 = On Bit 1 = Fill-in Bit 2 = Red-eye |  | Bit 3 = Slow-sync Bit 4 = Forced On Bit 5 = 2nd Curtain
> 0x0401 | FlashExposureComp | rational64s |
> 0x0403 | FlashRemoteControl | int16u |
> 0x0 = Off 0x1 = Channel 1, Low 0x2 = Channel 2, Low 0x3 = Channel 3, Low 0x4 = Channel 4, Low 0x9 = Channel 1, Mid 0xa = Channel 2, Mid |  | 0xb = Channel 3, Mid 0xc = Channel 4, Mid 0x11 = Channel 1, High 0x12 = Channel 2, High 0x13 = Channel 3, High 0x14 = Channel 4, High
> 0x0404 | FlashControlMode | int16u[n] | (3 or 4 values) [Value 0] 0 = Off 3 = TTL 4 = Auto 5 = Manual
> 0x0405 | FlashIntensity | rational64s[n] | (3 or 4 values) 'undef undef undef' = n/a 'undef undef undef undef' = n/a (x4)
> 0x0406 | ManualFlashStrength | rational64s[n] | (3 or 4 values) 'undef undef undef' = n/a 'undef undef undef undef' = n/a (x4)
> 0x0500 | WhiteBalance2 | int16u |
> 0 = Auto 1 = Auto (Keep Warm Color Off) 16 = 7500K (Fine Weather with Shade) 17 = 6000K (Cloudy) 18 = 5300K (Fine Weather) 20 = 3000K (Tungsten light) 21 = 3600K (Tungsten light-like) 22 = Auto Setup 23 = 5500K (Flash) 33 = 6600K (Daylight fluorescent) 34 = 4500K (Neutral white fluorescent) 35 = 4000K (Cool white fluorescent) 36 = White Fluorescent 48 = 3600K (Tungsten light-like) 67 = Underwater 256 = One Touch WB 1 257 = One Touch WB 2 258 = One Touch WB 3 259 = One Touch WB 4 512 = Custom WB 1 513 = Custom WB 2 514 = Custom WB 3 515 = Custom WB 4
> 0x0501 | WhiteBalanceTemperature | int16u |
> 0x0502 | WhiteBalanceBracket | int16s |
> 0x0503 | CustomSaturation | int16s[3]~ | (3 numbers: 1. CS Value, 2. Min, 3. Max)
> 0x0504 | ModifiedSaturation | int16u | 0 = Off 1 = CM1 (Red Enhance) 2 = CM2 (Green Enhance) 3 = CM3 (Blue Enhance) 4 = CM4 (Skin Tones)
> 0x0505 | ContrastSetting | int16s[3] | (value, min, max)
> 0x0506 | SharpnessSetting | int16s[3] | (value, min, max)
> 0x0507 | ColorSpace | int16u | 0 = sRGB 1 = Adobe RGB 2 = Pro Photo RGB
> 0x0509 | SceneMode | int16u |
> 0 = Standard 6 = Auto 7 = Sport 8 = Portrait 9 = Landscape+Portrait 10 = Landscape 11 = Night Scene 12 = Self Portrait 13 = Panorama 14 = 2 in 1 15 = Movie 16 = Landscape+Portrait 17 = Night+Portrait 18 = Indoor 19 = Fireworks 20 = Sunset 21 = Beauty Skin 22 = Macro 23 = Super Macro 24 = Food 25 = Documents 26 = Museum 27 = Shoot & Select 28 = Beach & Snow 29 = Self Protrait+Timer 30 = Candle 31 = Available Light 32 = Behind Glass 33 = My Mode 34 = Pet 35 = Underwater Wide1 |  | 36 = Underwater Macro 37 = Shoot & Select1 38 = Shoot & Select2 39 = High Key 40 = Digital Image Stabilization 41 = Auction 42 = Beach 43 = Snow 44 = Underwater Wide2 45 = Low Key 46 = Children 47 = Vivid 48 = Nature Macro 49 = Underwater Snapshot 50 = Shooting Guide 54 = Face Portrait 57 = Bulb 59 = Smile Shot 60 = Quick Shutter 63 = Slow Shutter 64 = Bird Watching 65 = Multiple Exposure 66 = e-Portrait 67 = Soft Background Shot 142 = Hand-held Starlight 154 = HDR 197 = Panning 203 = Light Trails 204 = Backlight HDR 205 = Silent 206 = Multi Focus Shot
> 0x050a | NoiseReduction | int16u | 0x0 = (none) Bit 0 = Noise Reduction Bit 1 = Noise Filter Bit 2 = Noise Filter (ISO Boost) Bit 3 = Auto
> 0x050b | DistortionCorrection | int16u | 0 = Off 1 = On
> 0x050c | ShadingCompensation | int16u | 0 = Off 1 = On
> 0x050d | CompressionFactor | rational64u |
> 0x050f | Gradation | int16s[n] | (3 or 4 values) [Values 0-2] '-1 -1 1' = Low Key '0 -1 1' = Normal '0 0 0' = n/a '1 -1 1' = High Key [Value 3] 0 = User-Selected 1 = Auto-Override
> 0x0520 | PictureMode | int16u[n] | (1 or 2 values) [Value 0]
> 1 = Vivid 2 = Natural 3 = Muted 4 = Portrait 5 = i-Enhance 6 = e-Portrait 7 = Color Creator 9 = Color Profile 1 10 = Color Profile 2 11 = Color Profile 3 12 = Monochrome Profile 1 13 = Monochrome Profile 2 14 = Monochrome Profile 3 256 = Monotone 512 = Sepia
> 0x0521 | PictureModeSaturation | int16s[3] | (value, min, max)
> 0x0522 | PictureModeHue? | int16s |
> 0x0523 | PictureModeContrast | int16s[3] | (value, min, max)
> 0x0524 | PictureModeSharpness | int16s[3] | (value, min, max)
> 0x0525 | PictureModeBWFilter | int16s |
> 0 = n/a 1 = Neutral 2 = Yellow |  | 3 = Orange 4 = Red 5 = Green
> 0x0526 | PictureModeTone | int16s |
> 0 = n/a 1 = Neutral 2 = Sepia |  | 3 = Blue 4 = Purple 5 = Green
> 0x0527 | NoiseFilter | int16s[3] | '-1 -2 1' = Low '-2 -2 1' = Off '0 -2 1' = Standard '0 0 0' = n/a '1 -2 1' = High
> 0x0529 | ArtFilter | int16u[4] | [Value 0]
> 0 = Off 1 = Soft Focus 2 = Pop Art 3 = Pale & Light Color 4 = Light Tone 5 = Pin Hole 6 = Grainy Film 9 = Diorama 10 = Cross Process 12 = Fish Eye 13 = Drawing 14 = Gentle Sepia 15 = Pale & Light Color II 16 = Pop Art II 17 = Pin Hole II 18 = Pin Hole III 19 = Grainy Film II 20 = Dramatic Tone 21 = Punk |  | 22 = Soft Focus 2 23 = Sparkle 24 = Watercolor 25 = Key Line 26 = Key Line II 27 = Miniature 28 = Reflection 29 = Fragmented 31 = Cross Process II 32 = Dramatic Tone II 33 = Watercolor I 34 = Watercolor II 35 = Diorama II 36 = Vintage 37 = Vintage II 38 = Vintage III 39 = Partial Color 40 = Partial Color II 41 = Partial Color III
> 0x052c | MagicFilter | int16u[4] | [Value 0]
> 0 = Off 1 = Soft Focus 2 = Pop Art 3 = Pale & Light Color 4 = Light Tone 5 = Pin Hole 6 = Grainy Film 9 = Diorama 10 = Cross Process 12 = Fish Eye 13 = Drawing 14 = Gentle Sepia 15 = Pale & Light Color II 16 = Pop Art II 17 = Pin Hole II 18 = Pin Hole III 19 = Grainy Film II 20 = Dramatic Tone 21 = Punk |  | 22 = Soft Focus 2 23 = Sparkle 24 = Watercolor 25 = Key Line 26 = Key Line II 27 = Miniature 28 = Reflection 29 = Fragmented 31 = Cross Process II 32 = Dramatic Tone II 33 = Watercolor I 34 = Watercolor II 35 = Diorama II 36 = Vintage 37 = Vintage II 38 = Vintage III 39 = Partial Color 40 = Partial Color II 41 = Partial Color III
> 0x052d | PictureModeEffect | int16s[3] | '-1 -1 1' = Low '0 -1 1' = Standard '0 0 0' = n/a '1 -1 1' = High
> 0x052e | ToneLevel | yes | [Values 0, 4, 8, 12, 16, 20 and 24] -31999 = Highlights -31998 = Shadows -31997 = Midtones 0 = 0
> 0x052f | ArtFilterEffect | int16u[20] | [Value 0]
> 0x0 = Off 0x1 = Soft Focus 0x2 = Pop Art 0x3 = Pale & Light Color 0x4 = Light Tone 0x5 = Pin Hole 0x6 = Grainy Film 0x9 = Diorama 0xa = Cross Process 0xc = Fish Eye 0xd = Drawing 0xe = Gentle Sepia 0xf = Pale & Light Color II 0x10 = Pop Art II 0x11 = Pin Hole II 0x12 = Pin Hole III 0x13 = Grainy Film II 0x14 = Dramatic Tone 0x15 = Punk |  | 0x16 = Soft Focus 2 0x17 = Sparkle 0x18 = Watercolor 0x19 = Key Line 0x1a = Key Line II 0x1b = Miniature 0x1c = Reflection 0x1d = Fragmented 0x1f = Cross Process II 0x20 = Dramatic Tone II 0x21 = Watercolor I 0x22 = Watercolor II 0x23 = Diorama II 0x24 = Vintage 0x25 = Vintage II 0x26 = Vintage III 0x27 = Partial Color 0x28 = Partial Color II 0x29 = Partial Color III
> [Value 4]
> 0x0 = No Effect 0x8010 = Star Light 0x8020 = Pin Hole 0x8030 = Frame 0x8040 = Soft Focus |  | 0x8050 = White Edge 0x8060 = B&W 0x8080 = Blur Top and Bottom 0x8081 = Blur Left and Right
> [Value 6]
> 0x0 = No Color Filter 0x1 = Yellow Color Filter 0x2 = Orange Color Filter |  | 0x3 = Red Color Filter 0x4 = Green Color Filter
> 0x0532 | ColorCreatorEffect | int16s[6] |
> 0x0537 | MonochromeProfileSettings | int16s[6] | [Value 0]
> 0 = No Filter 1 = Yellow Filter 2 = Orange Filter 3 = Red Filter 4 = Magenta Filter |  | 5 = Blue Filter 6 = Cyan Filter 7 = Green Filter 8 = Yellow-green Filter
> 0x0538 | FilmGrainEffect | int16s | 0 = Off 1 = Low 2 = Medium 3 = High
> 0x0539 | ColorProfileSettings | int16s[14] |
> 0x053a | MonochromeVignetting | int16s | (-5 to +5: positive is white vignetting, negative is black vignetting)
> 0x053b | MonochromeColor | int16s |
> 0 = (none) 1 = Normal 2 = Sepia |  | 3 = Blue 4 = Purple 5 = Green
> 0x0600 | DriveMode | int16u[n]~ | (2, 3 or 5 numbers: 1. Mode, 2. Shot number, 3. Mode bits, 5. Shutter mode)
> 0x0601 | PanoramaMode | int16u~ | (2 numbers: 1. Mode, 2. Shot number)
> 0x0603 | ImageQuality2 | int16u | 1 = SQ 2 = HQ 3 = SHQ 4 = RAW 5 = SQ (5)
> 0x0604 | ImageStabilization | int32u | 0 = Off 1 = On, Mode 1 2 = On, Mode 2 3 = On, Mode 3 4 = On, Mode 4
> 0x0804 | StackedImage | int32u[2] |
> '0 0' = No '3 2' = ND2 (1EV) '3 4' = ND4 (2EV) '3 8' = ND8 (3EV) '3 16' = ND16 (4EV) '3 32' = ND32 (5EV) '3 64' = ND64 (6EV) '5 4' = HDR1 '6 4' = HDR2 '8 8' = Tripod high resolution '11 12' = Hand-held high resolution (11 12) '11 16' = Hand-held high resolution (11 16) '1 *' = Live Composite (* images) '4 *' = Live Time/Bulb (* images) '9 *' = Focus-stacked (* images)
> 0x0900 | ManometerPressure | int16u |
> 0x0901 | ManometerReading | int32s[2] |
> 0x0902 | ExtendedWBDetect | int16u | 0 = Off 1 = On
> 0x0903 | RollAngle | int16s[2] | (converted to degrees of clockwise camera rotation)
> 0x0904 | PitchAngle | int16s[2] | (converted to degrees of upward camera tilt)
> 0x0908 | DateTimeUTC | string |

## Olympus RawDevelopment Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | RawDevVersion | undef[4] |
> 0x0100 | RawDevExposureBiasValue | rational64s |
> 0x0101 | RawDevWhiteBalanceValue | int16u |
> 0x0102 | RawDevWBFineAdjustment | int16s |
> 0x0103 | RawDevGrayPoint | int16u[3] |
> 0x0104 | RawDevSaturationEmphasis | int16s[3] |
> 0x0105 | RawDevMemoryColorEmphasis | int16u |
> 0x0106 | RawDevContrastValue | int16s[3] |
> 0x0107 | RawDevSharpnessValue | int16s[3] |
> 0x0108 | RawDevColorSpace | int16u | 0 = sRGB 1 = Adobe RGB 2 = Pro Photo RGB
> 0x0109 | RawDevEngine | int16u | 0 = High Speed 1 = High Function 2 = Advanced High Speed 3 = Advanced High Function
> 0x010a | RawDevNoiseReduction | int16u | 0x0 = (none) Bit 0 = Noise Reduction Bit 1 = Noise Filter Bit 2 = Noise Filter (ISO Boost)
> 0x010b | RawDevEditStatus | int16u | 0 = Original 1 = Edited (Landscape) 6 = Edited (Portrait) 8 = Edited (Portrait)
> 0x010c | RawDevSettings | int16u |
> 0x0 = (none) Bit 0 = WB Color Temp Bit 1 = WB Gray Point Bit 2 = Saturation Bit 3 = Contrast |  | Bit 4 = Sharpness Bit 5 = Color Space Bit 6 = High Function Bit 7 = Noise Reduction

## Olympus RawDevelopment2 Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | RawDevVersion | undef[4] |
> 0x0100 | RawDevExposureBiasValue | rational64s |
> 0x0101 | RawDevWhiteBalance | int16u | 1 = Color Temperature 2 = Gray Point
> 0x0102 | RawDevWhiteBalanceValue | int16u |
> 0x0103 | RawDevWBFineAdjustment | int16s |
> 0x0104 | RawDevGrayPoint | int16u[3] |
> 0x0105 | RawDevContrastValue | int16s[3] |
> 0x0106 | RawDevSharpnessValue | int16s[3] |
> 0x0107 | RawDevSaturationEmphasis | int16s[3] |
> 0x0108 | RawDevMemoryColorEmphasis | int16u |
> 0x0109 | RawDevColorSpace | int16u | 0 = sRGB 1 = Adobe RGB 2 = Pro Photo RGB
> 0x010a | RawDevNoiseReduction | int16u | 0x0 = (none) Bit 0 = Noise Reduction Bit 1 = Noise Filter Bit 2 = Noise Filter (ISO Boost)
> 0x010b | RawDevEngine | int16u | 0 = High Speed 1 = High Function
> 0x010c | RawDevPictureMode | int16u | 1 = Vivid 2 = Natural 3 = Muted 256 = Monotone 512 = Sepia
> 0x010d | RawDevPMSaturation | int16s[3] |
> 0x010e | RawDevPMContrast | int16s[3] |
> 0x010f | RawDevPMSharpness | int16s[3] |
> 0x0110 | RawDevPM_BWFilter | int16u | 1 = Neutral 2 = Yellow 3 = Orange 4 = Red 5 = Green
> 0x0111 | RawDevPMPictureTone | int16u | 1 = Neutral 2 = Sepia 3 = Blue 4 = Purple 5 = Green
> 0x0112 | RawDevGradation | int16s[3] |
> 0x0113 | RawDevSaturation3 | int16s[3] |
> 0x0119 | RawDevAutoGradation | int16u | 0 = Off 1 = On
> 0x0120 | RawDevPMNoiseFilter | int16u |
> 0x0121 | RawDevArtFilter | int16u[4] | [Value 0]
> 0 = Off 1 = Soft Focus 2 = Pop Art 3 = Pale & Light Color 4 = Light Tone 5 = Pin Hole 6 = Grainy Film 9 = Diorama 10 = Cross Process 12 = Fish Eye 13 = Drawing 14 = Gentle Sepia 15 = Pale & Light Color II 16 = Pop Art II 17 = Pin Hole II 18 = Pin Hole III 19 = Grainy Film II 20 = Dramatic Tone 21 = Punk |  | 22 = Soft Focus 2 23 = Sparkle 24 = Watercolor 25 = Key Line 26 = Key Line II 27 = Miniature 28 = Reflection 29 = Fragmented 31 = Cross Process II 32 = Dramatic Tone II 33 = Watercolor I 34 = Watercolor II 35 = Diorama II 36 = Vintage 37 = Vintage II 38 = Vintage III 39 = Partial Color 40 = Partial Color II 41 = Partial Color III

## Olympus ImageProcessing Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | ImageProcessingVersion | undef[4] |
> 0x0100 | WB_RBLevels | int16u[2] |
> 0x0102 | WB_RBLevels3000K | int16u[2] |
> 0x0103 | WB_RBLevels3300K | int16u[2] |
> 0x0104 | WB_RBLevels3600K | int16u[2] |
> 0x0105 | WB_RBLevels3900K | int16u[2] |
> 0x0106 | WB_RBLevels4000K | int16u[2] |
> 0x0107 | WB_RBLevels4300K | int16u[2] |
> 0x0108 | WB_RBLevels4500K | int16u[2] |
> 0x0109 | WB_RBLevels4800K | int16u[2] |
> 0x010a | WB_RBLevels5300K | int16u[2] |
> 0x010b | WB_RBLevels6000K | int16u[2] |
> 0x010c | WB_RBLevels6600K | int16u[2] |
> 0x010d | WB_RBLevels7500K | int16u[2] |
> 0x010e | WB_RBLevelsCWB1 | int16u[2] |
> 0x010f | WB_RBLevelsCWB2 | int16u[2] |
> 0x0110 | WB_RBLevelsCWB3 | int16u[2] |
> 0x0111 | WB_RBLevelsCWB4 | int16u[2] |
> 0x0113 | WB_GLevel3000K | int16u |
> 0x0114 | WB_GLevel3300K | int16u |
> 0x0115 | WB_GLevel3600K | int16u |
> 0x0116 | WB_GLevel3900K | int16u |
> 0x0117 | WB_GLevel4000K | int16u |
> 0x0118 | WB_GLevel4300K | int16u |
> 0x0119 | WB_GLevel4500K | int16u |
> 0x011a | WB_GLevel4800K | int16u |
> 0x011b | WB_GLevel5300K | int16u |
> 0x011c | WB_GLevel6000K | int16u |
> 0x011d | WB_GLevel6600K | int16u |
> 0x011e | WB_GLevel7500K | int16u |
> 0x011f | WB_GLevel | int16u |
> 0x0200 | ColorMatrix | int16u[9] |
> 0x0300 | Enhancer | int16u |
> 0x0301 | EnhancerValues | int16u[7] |
> 0x0310 | CoringFilter | int16u |
> 0x0311 | CoringValues | int16u[7] |
> 0x0600 | BlackLevel2 | int16u[4] |
> 0x0610 | GainBase | int16u |
> 0x0611 | ValidBits | int16u[2] |
> 0x0612 | CropLeft | int16u[2] |
> 0x0613 | CropTop | int16u[2] |
> 0x0614 | CropWidth | int32u |
> 0x0615 | CropHeight | int32u |
> 0x0635 | UnknownBlock1? | undef | (large unknown data block in ORF images but not JPG images)
> 0x0636 | UnknownBlock2? | undef | (large unknown data block in ORF images but not JPG images)
> 0x0805 | SensorCalibration | int16s[2] | (2 numbers: 1. Recommended maximum, 2. Calibration midpoint)
> 0x1010 | NoiseReduction2 | int16u | 0x0 = (none) Bit 0 = Noise Reduction Bit 1 = Noise Filter Bit 2 = Noise Filter (ISO Boost)
> 0x1011 | DistortionCorrection2 | int16u | 0 = Off 1 = On
> 0x1012 | ShadingCompensation2 | int16u | 0 = Off 1 = On
> 0x101c | MultipleExposureMode | int16u[2] | [Value 0] 0 = Off 1 = Live Composite 2 = On (2 frames) 3 = On (3 frames)
> 0x1103 | UnknownBlock3? | undef | (large unknown data block in ORF images but not JPG images)
> 0x1104 | UnknownBlock4? | undef | (large unknown data block in ORF images but not JPG images)
> 0x1112 | AspectRatio | int8u[2] |
> '1 1' = 4:3 '1 4' = 1:1 '2 1' = 3:2 (RAW) '2 2' = 3:2 '3 1' = 16:9 (RAW) '3 3' = 16:9 '4 1' = 1:1 (RAW) |  | '4 4' = 6:6 '5 5' = 5:4 '6 6' = 7:6 '7 7' = 6:5 '8 8' = 7:5 '9 1' = 3:4 (RAW) '9 9' = 3:4
> 0x1113 | AspectFrame | int16u[4] |
> 0x1200 | FacesDetected | int32u[n] | (2 or 3 values)
> 0x1201 | FaceDetectArea | int16s[n] | (for models with 2 values in FacesDetected this gives X/Y coordinates in the FaceDetectFrame for all 4 corners of the face rectangle. For models with 3 values in FacesDetected this gives X/Y coordinates, size and rotation angle of the face detect square)
> 0x1202 | MaxFaces | int32u[3] |
> 0x1203 | FaceDetectFrameSize | int16u[6] | (width/height of the full face detect frame)
> 0x1207 | FaceDetectFrameCrop | int16s[12] | (X/Y offset and width/height of the cropped face detect frame)
> 0x1306 | CameraTemperature | no | (this seems to be in degrees C only for some models)
> 0x1900 | KeystoneCompensation | int8u[2] | '0 0' = Off '0 1' = On
> 0x1901 | KeystoneDirection | int8u[2] | 0 = Vertical 1 = Horizontal
> 0x1906 | KeystoneValue | int16s[3] | (3 numbers: 1. Keystone Value, 2. Min, 3. Max)

## Olympus FocusInfo Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | FocusInfoVersion | undef[4] |
> 0x0209 | AutoFocus? | int16u | 0 = Off 1 = On
> 0x0210 | SceneDetect | int16u |
> 0x0211 | SceneArea? | int32u[8] |
> 0x0212 | SceneDetectData? | int32u[720] |
> 0x0300 | ZoomStepCount | int16u |
> 0x0301 | FocusStepCount | int16u |
> 0x0303 | FocusStepInfinity | int16u |
> 0x0304 | FocusStepNear | int16u |
> 0x0305 | FocusDistance | rational64u |
> 0x0308 | AFPoint | int16u | (for the E-3, E-5 and E-30 the value is separated into 2 parts: low 5 bits give AF point, upper bits give AF target selection mode) [Value 0]
> 0x0 = (none) 0x1 = Top-left (horizontal) 0x2 = Top-center (horizontal) 0x3 = Top-right (horizontal) 0x4 = Left (horizontal) 0x5 = Mid-left (horizontal) 0x6 = Center (horizontal) 0x7 = Mid-right (horizontal) 0x8 = Right (horizontal) 0x9 = Bottom-left (horizontal) 0xa = Bottom-center (horizontal) 0xb = Bottom-right (horizontal) |  | 0xc = Top-left (vertical) 0xd = Top-center (vertical) 0xe = Top-right (vertical) 0xf = Left (vertical) 0x10 = Mid-left (vertical) 0x11 = Center (vertical) 0x12 = Mid-right (vertical) 0x13 = Right (vertical) 0x14 = Bottom-left (vertical) 0x15 = Bottom-center (vertical) 0x16 = Bottom-right (vertical) 0x1f = n/a
> [Value 1]
> 0x0 = Single Target 0x40 = All Target |  | 0x80 = Dynamic Single Target 0xe0 = n/a
> (models with 7-point AF) [Value 0]
> 0x0 = (none) 0x2 = Top-center (horizontal) 0x4 = Right (horizontal) 0x5 = Mid-right (horizontal) 0x6 = Center (horizontal) 0x7 = Mid-left (horizontal) 0x8 = Left (horizontal) 0xa = Bottom-center (horizontal) 0xc = Top-center (vertical) 0xf = Right (vertical) 0x10 = Mid-right (vertical) 0x11 = Center (vertical) 0x12 = Mid-left (vertical) 0x13 = Left (vertical) 0x15 = Bottom-center (vertical)
> [Value 1] 0x0 = Single Target 0x40 = All Target (models other than E-Mxxx and OM-x) 0 = Left (or n/a) 1 = Center (horizontal) 2 = Right 3 = Center (vertical) 255 = None (other models)
> 0x031b | AFPointDetails AFPointDetails | no int16u | (models E-Mxxx and OM-x) [Value 0]
> 0x0 = No Subject Detection 0x1 = Motorsports |  | 0x2 = Airplanes 0x3 = Trains |  | 0x4 = Birds 0x5 = Dogs & Cats
> [Value 1]
> 0x0 = Face Priority |  | 0x1 = Target Priority
> [Value 2]
> 0x0 = Normal AF |  | 0x1 = AF on Half Press
> [Value 3]
> 0x0 = No Eye-AF |  | 0x1 = Right Eye Priority |  | 0x2 = Left Eye Priority |  | 0x3 = Both Eyes Priority
> [Value 4]
> 0x0 = No Face Detection |  | 0x1 = Face Detection
> [Value 5]
> 0x0 = No MF |  | 0x1 = With MF
> [Value 6]
> 0x0 = AF Priority |  | 0x1 = Release Priority
> [Value 7]
> 0x0 = No Object found |  | 0x1 = Object found
> [Value 8]
> 0x0 = MF |  | 0x1 = S-AF |  | 0x2 = C-AF |  | 0x6 = C-AF + TR
> (other models)
> 0x0328 | AFInfo | - | --> Olympus AFInfo Tags
> 0x1201 | ExternalFlash | int16u[2] | '0 0' = Off '1 0' = On
> 0x1203 | ExternalFlashGuideNumber? | rational64s |
> 0x1204 | ExternalFlashBounce | int16u | 0 = Bounce or Off 1 = Direct
> 0x1205 | ExternalFlashZoom | rational64u |
> 0x1208 | InternalFlash | int16u[n] | 0 = Off 1 = On '0 0' = Off '1 0' = On
> 0x1209 | ManualFlash | int16u[2]~ | (2 numbers: 1. 0=Off, 1=On, 2. Flash strength)
> 0x120a | MacroLED | int16u | 0 = Off 1 = On
> 0x1500 | SensorTemperature | int16s |
> 0x1600 | ImageStabilization | undef~ |

## Olympus AFInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> [no tags known]

## Olympus FE Tags

Some FE models write a large number of tags here, but most of this information remains unknown.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0100 | BodyFirmwareVersion | string |

## Olympus RawInfo Tags

These tags are found only in ORF images of some models (eg. C8080WZ).

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0x0000 | RawInfoVersion | undef[4] |
> 0x0100 | WB_RBLevelsUsed | int16u[2] |
> 0x0110 | WB_RBLevelsAuto | int16u[2] |
> 0x0120 | WB_RBLevelsShade | int16u[2] |
> 0x0121 | WB_RBLevelsCloudy | int16u[2] |
> 0x0122 | WB_RBLevelsFineWeather | int16u[2] |
> 0x0123 | WB_RBLevelsTungsten | int16u[2] |
> 0x0124 | WB_RBLevelsEveningSunlight | int16u[2] |
> 0x0130 | WB_RBLevelsDaylightFluor | int16u[2] |
> 0x0131 | WB_RBLevelsDayWhiteFluor | int16u[2] |
> 0x0132 | WB_RBLevelsCoolWhiteFluor | int16u[2] |
> 0x0133 | WB_RBLevelsWhiteFluorescent | int16u[2] |
> 0x0200 | ColorMatrix2 | int16u[9] |
> 0x0310 | CoringFilter | int16u |
> 0x0311 | CoringValues | int16u[11] |
> 0x0600 | BlackLevel2 | int16u[4] |
> 0x0601 | YCbCrCoefficients | no | (stored as int16u[6], but extracted as rational32u[3])
> 0x0611 | ValidPixelDepth | int16u[2] |
> 0x0612 | CropLeft | int16u |
> 0x0613 | CropTop | int16u |
> 0x0614 | CropWidth | int32u |
> 0x0615 | CropHeight | int32u |
> 0x1000 | LightSource | int16u |
> 0 = Unknown 16 = Shade 17 = Cloudy 18 = Fine Weather 20 = Tungsten (Incandescent) 22 = Evening Sunlight 33 = Daylight Fluorescent 34 = Day White Fluorescent 35 = Cool White Fluorescent 36 = White Fluorescent 256 = One Touch White Balance 512 = Custom 1-4
> 0x1001 | WhiteBalanceComp | int16s[3] |
> 0x1010 | SaturationSetting | int16s[3] |
> 0x1011 | HueSetting | int16s[3] |
> 0x1012 | ContrastSetting | int16s[3] |
> 0x1013 | SharpnessSetting | int16s[3] |
> 0x2000 | CMExposureCompensation | rational64s |
> 0x2001 | CMWhiteBalance | int16u |
> 0x2002 | CMWhiteBalanceComp | int16s |
> 0x2010 | CMWhiteBalanceGrayPoint | int16u[3] |
> 0x2020 | CMSaturation | int16s[3] |
> 0x2021 | CMHue | int16s[3] |
> 0x2022 | CMContrast | int16s[3] |
> 0x2023 | CMSharpness | int16s[3] |

## Olympus UnknownInfo Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> [no tags known]

## Olympus DSS Tags

Information extracted from DSS/DS2 files and the ID3 XOLY frame of MP3 files written by some Olympus voice recorders.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 12 | Model | no |
> 38 | StartTime | no |
> 50 | EndTime | no |
> 62 | Duration | no |
> 798 | Comment | no |

## Olympus AVI Tags

This information is found in Olympus AVI videos.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 18 | Make | no |
> 44 | Model | no | --> Olympus CameraType Values
> 94 | FNumber | no |
> 131 | DateTime1 | no |
> 157 | DateTime2 | no |
> 297 | ThumbInfo | - | --> Olympus thmb2 Tags

## Olympus thmb2 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ThumbnailWidth | no |
> 2 | ThumbnailHeight | no |
> 4 | ThumbnailLength | no |
> 8 | ThumbnailImage | no | (160x120 JPEG thumbnail image)

## Olympus WAV Tags

This information is found in WAV files from Olympus PCM linear recorders like the LS-5, LS-10, LS-11.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 12 | Model | no |
> 28 | FileNumber | no |
> 38 | DateTimeOriginal | no | (time at start of recording)
> 50 | DateTimeEnd | no | (time at end of recording)
> 62 | RecordingTime | no |
> 512 | Duration | no |
> 522 | Index01 | no |
> 532 | Index02 | no |
> 542 | Index03 | no |
> 552 | Index04 | no |
> 562 | Index05 | no |
> 572 | Index06 | no |
> 582 | Index07 | no |
> 592 | Index08 | no |
> 602 | Index09 | no |
> 612 | Index10 | no |
> 622 | Index11 | no |
> 632 | Index12 | no |
> 642 | Index13 | no |
> 652 | Index14 | no |
> 662 | Index15 | no |
> 672 | Index16 | no |

## Olympus MOV1 Tags

This information is found in MOV videos from Olympus models such as the D540Z, D595Z, FE100, FE110, FE115, FE170 and FE200.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | Make | no |
> 24 | Model | no | --> Olympus CameraType Values
> 38 | ExposureUnknown? | no |
> 42 | FNumber | no |
> 50 | ExposureCompensation | no |
> 72 | FocalLength | no |

## Olympus MOV2 Tags

This information is found in MOV videos from Olympus models such as the FE120, FE140 and FE190.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | Make | no |
> 24 | Model | no | (the actual model name, no decoding necessary)
> 54 | ExposureTime | no |
> 58 | FNumber | no |
> 66 | ExposureCompensation | no |
> 88 | FocalLength | no |
> 193 | ISO | no |

## Olympus MP4 Tags

This information is found in MP4 videos from Olympus models such as the u7040 and u9010.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | Make | no |
> 24 | Model | no | (oddly different than CameraType values in JPEG images by the same camera)
> 'SG472' = u7040,S7040 'SG473' = u9010,S9010 'SG475' = SP800UZ 'SG551' = SZ-30MR 'SG553' = SP-610UZ |  | 'SG554' = SZ-10 'SG555' = SZ-20 'SG573' = SZ-14 'SG575' = SP-620UZ
> 40 | FNumber | no |
> 48 | ExposureCompensation | no |
> 104 | MovableInfo | - | --> Olympus MovableInfo Tags
> 114 | MovableInfo | - | --> Olympus MovableInfo Tags

## Olympus MovableInfo Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 4 | ISO | no |
> 44 | EncoderVersion | no |
> 60 | DecoderVersion | no |
> 131 | Thumbnail | - | --> Olympus Thumbnail Tags

## Olympus Thumbnail Tags

> Index4 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 1 | ThumbnailWidth | no |
> 2 | ThumbnailHeight | no |
> 3 | ThumbnailLength | no |
> 4 | ThumbnailOffset | no |

## Olympus MOV3 Tags

QuickTime information found in the TAGS atom of MOV videos from the E-M5.

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 'OLYM' | OlympusAtom | - | --> Olympus OLYM2 Tags

## Olympus OLYM2 Tags

> Tag ID | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 'prms' | MakerNotes | - | --> Olympus prms Tags
> 'scrn' | PreviewInfo | - | --> Olympus scrn2 Tags
> 'thmb' | ThumbInfo | - | --> Olympus thmb2 Tags

## Olympus prms Tags

Information extracted from the "prms" atom in MOV videos from Olympus models such as the OM E-M5.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 18 | Make | no |
> 44 | Model | no | --> Olympus CameraType Values
> 131 | DateTime1 | no |
> 157 | DateTime2 | no |
> 383 | LensModel | no |

## Olympus scrn2 Tags

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 2 | OlympusPreview | - | --> Olympus scrn Tags

## Olympus scrn Tags

Information extracted from the "scrn" atom of Olympus MP4 videos.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | PreviewImageLength | no |
> 4 | PreviewImage | no | (640x480 JPEG preview image)

## Olympus thmb Tags

Information extracted from the "thmb" atom of Olympus MP4 videos.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 0 | ThumbnailLength | no |
> 4 | ThumbnailImage | no | (160x120 JPEG thumbnail image)

## Olympus OLYM Tags

Tags found in the OLYM atom of MP4 videos from the TG-810.

> Index1 | Tag Name | Writable | Values / Notes
> --- | --- | --- | ---
> 14 | Make | no |
> 40 | Model | no | --> Olympus CameraType Values
> 90 | FNumber | no |
> 127 | DateTimeOriginal | no |
> 153 | DateTime2 | no |
> 265 | ThumbnailWidth | no |
> 267 | ThumbnailHeight | no |

(This document generated automatically by Image::ExifTool::BuildTagLookup)
Last revised Mar 27, 2024

<-- ExifTool Tag Names